@@ -7,16 +7,11 @@ use serde::Serialize;
 
 use crate::keys::{EmptyPrefix, Prefixer, PrimaryKey};
 use crate::prefix::{Bound, Prefix};
-use crate::snapshot::SnapshotMap;
+use crate::snapshot_map::SnapshotMap;
 use crate::{IndexList, Path, Strategy};
 
 /// IndexedSnapshotMap works like a SnapshotMap but has a secondary index
-pub struct IndexedSnapshotMap<'a, K, T, I>
-where
-    K: PrimaryKey<'a>,
-    T: Serialize + DeserializeOwned + Clone,
-    I: IndexList<T>,
-{
+pub struct IndexedSnapshotMap<'a, K, T, I> {
     pk_namespace: &'a [u8],
     primary: SnapshotMap<'a, K, T>,
     /// This is meant to be read directly to get the proper types, like:
@@ -24,12 +19,7 @@ where
     pub idx: I,
 }
 
-impl<'a, K, T, I> IndexedSnapshotMap<'a, K, T, I>
-where
-    K: PrimaryKey<'a>,
-    T: Serialize + DeserializeOwned + Clone,
-    I: IndexList<T>,
-{
+impl<'a, K, T, I> IndexedSnapshotMap<'a, K, T, I> {
     pub fn new(
         pk_namespace: &'a str,
         checkpoints: &'a str,
@@ -43,14 +33,6 @@ where
             idx: indexes,
         }
     }
-
-    pub fn add_checkpoint(&self, store: &mut dyn Storage, height: u64) -> StdResult<()> {
-        self.primary.add_checkpoint(store, height)
-    }
-
-    pub fn remove_checkpoint(&self, store: &mut dyn Storage, height: u64) -> StdResult<()> {
-        self.primary.remove_checkpoint(store, height)
-    }
 }
 
 impl<'a, K, T, I> IndexedSnapshotMap<'a, K, T, I>
@@ -59,6 +41,14 @@ where
     K: PrimaryKey<'a> + Prefixer<'a>,
     I: IndexList<T>,
 {
+    pub fn add_checkpoint(&self, store: &mut dyn Storage, height: u64) -> StdResult<()> {
+        self.primary.add_checkpoint(store, height)
+    }
+
+    pub fn remove_checkpoint(&self, store: &mut dyn Storage, height: u64) -> StdResult<()> {
+        self.primary.remove_checkpoint(store, height)
+    }
+
     pub fn may_load_at_height(
         &self,
         store: &dyn Storage,
